( cd usr/lib64 ; rm -rf libgmp.so )
( cd usr/lib64 ; ln -sf libgmp.so.3.4.3 libgmp.so )
( cd usr/lib64 ; rm -rf libmp.so.3 )
( cd usr/lib64 ; ln -sf libmp.so.3.1.12 libmp.so.3 )
( cd usr/lib64 ; rm -rf libgmp.so.3 )
( cd usr/lib64 ; ln -sf libgmp.so.3.4.3 libgmp.so.3 )
( cd usr/lib64 ; rm -rf libgmpxx.so )
( cd usr/lib64 ; ln -sf libgmpxx.so.4.0.3 libgmpxx.so )
( cd usr/lib64 ; rm -rf libgmpxx.so.4 )
( cd usr/lib64 ; ln -sf libgmpxx.so.4.0.3 libgmpxx.so.4 )
( cd usr/lib64 ; rm -rf libmp.so )
( cd usr/lib64 ; ln -sf libmp.so.3.1.12 libmp.so )
